@@ -15,7 +15,7 @@ colors (
 
 title(Ascii::Text->new(font => 'Boomer', align => 'center')->stringify('MATRIX', 1));
 
-abstract('script for generating heavinly digital rain');
+abstract('script for generating heavenly digital rain');
 
 option delay => (
 	type => Int,
